@@ -215,7 +215,7 @@ ipw2 <- function(data,times=NULL,entrytime=NULL,time="time",cause="cause",
      strata=NULL,obs.only=TRUE,cens.formula=NULL,cens.code=0,
      pair.cweight="pcw",pair.tweight="ptw",pair.weight="weights",
      cname="cweights",tname="tweights",weight.name="indi.weights",
-     prec.factor=100)
+     prec.factor=100,...)
 { ## {{{ 
    ### first calculates weights based on marginal
    ### estimators  of censoring and truncation
